import Taro from '@tarojs/taro-h5';
import Nerv from "nervjs";
import RMCPicker from "./RMCPicker";
import RMCMultiPicker from "./MultiPicker";
import { View } from '@tarojs/components';
import arrayTreeFilter from 'array-tree-filter';
import { objectToString } from "../../common/utils";
const RMCPickerItem = RMCPicker.Item;
// 使用小程序原生组件样式不太一样
const wxPrefix = Taro.getEnv() === Taro.ENV_TYPE.WEAPP ? '-wx' : '';
function getDefaultProps() {
  return {
    prefixCls: `at-picker${wxPrefix}`,
    pickerPrefixCls: `at-picker-col${wxPrefix}`,
    cols: 3,
    cascade: true,
    value: [],
    onChange() {}
  };
}
export default class AtPickerView extends Taro.Component {
  constructor() {
    super(...arguments);
    this.onValueChange = (value, index) => {
      const children = arrayTreeFilter(this.props.data, (c, level) => {
        return level <= index && c.value === value[level];
      });
      let data = children[index];
      let i;
      for (i = index + 1; data && data.children && data.children.length && i < this.props.cols; i++) {
        data = data.children[0];
        value[i] = data.value;
      }
      value.length = i;
      this.setState({ value });
      if (this.props.onChange) {
        this.props.onChange(value);
      }
    };
    this.isMultiPicker = () => {
      if (!this.props.data) {
        return false;
      }
      return Array.isArray(this.props.data[0]);
    };
    this.onChangeWeapp = evt => {
      const { data, cascade, cols, onChange, value } = this.props;
      const valueOld = cascade ? this.state.value : value;
      const formattedData = this.getFormatData(cascade, data, valueOld, cols);
      const valueWeapp = evt.detail.value;
      const valueNew = formattedData.filter(item => item.length > 0).map((item, index) => item[valueWeapp[index]].value);
      if (!cascade) {
        onChange && onChange(valueNew);
      } else {
        this.onValueChange(valueNew, valueOld.findIndex((item, index) => item !== valueNew[index]));
      }
    };
    this.getFormatData = (cascade, data, valueNow, cols) => {
      const formattedData = cascade ? arrayTreeFilter(data, (c, level) => {
        return c.value === valueNow[level];
      }).map(c => c.children || []) : this.isMultiPicker() ? data : [data];
      // in case the users data is async get when select change
      if (cascade) {
        const needPad = cols - formattedData.length;
        if (needPad > 0) {
          for (let i = 0; i < needPad; i++) {
            formattedData.push([]);
          }
        }
        formattedData.length = cols - 1;
        formattedData.unshift(data);
      }
      return formattedData;
    };
    this.state = {
      value: this.getValue(this.props.data, this.props.value),
      isWEAPP: Taro.getEnv() === Taro.ENV_TYPE.WEAPP
    };
  }
  componentWillReceiveProps(nextProps) {
    if ('value' in nextProps) {
      this.setState({
        value: this.getValue(nextProps.data, nextProps.value)
      });
    }
  }
  getValue(d, val) {
    let data = d || this.props.data;
    let value = val || this.props.value;
    if (!value || !value.length || value.indexOf(undefined) > -1) {
      value = [];
      for (let i = 0; i < this.props.cols; i++) {
        if (data && data.length) {
          value[i] = data[0].value;
          data = data[0].children;
        }
      }
    }
    return value;
  }
  render() {
    const { data, pickerPrefixCls, indicatorStyle, maskStyle, cascade, value, prefixCls, cols, onChange } = this.props;
    if (!data) {
      return <View />;
    }
    const valueNow = cascade ? this.state.value : value;
    const formattedData = this.getFormatData(cascade, data, valueNow, cols) || [];
    const valueWeapp = valueNow ? valueNow.map((item, index) => {
      return formattedData[index] ? formattedData[index].findIndex(cell => cell.value === item) : 0;
    }) : [];
    const itemClassName = `${pickerPrefixCls}-item`;
    const multiStyle = {
      flexDirection: 'row',
      alignItems: 'center'
    };
    const stringIndicatorStyle = objectToString(indicatorStyle);
    const stringMaskStyle = objectToString(maskStyle);
    return cascade ? <RMCMultiPicker style={multiStyle} prefixCls={prefixCls} selectedValue={this.state.value} onValueChange={this.onValueChange}>
        {formattedData.map((childrenItems = [], level) => <RMCPicker key={level} prefixCls={pickerPrefixCls} style={{ flex: 1 }} disabled={false} indicatorStyle={indicatorStyle} maskStyle={maskStyle}>
            {childrenItems.map(item => <RMCPickerItem value={item.value} key={item.value}>
                {item.label}
              </RMCPickerItem>)}
          </RMCPicker>)}
      </RMCMultiPicker> : <RMCMultiPicker prefixCls={prefixCls} selectedValue={value} onValueChange={onChange} style={{ flexDirection: 'row' }}>
        {formattedData.map((col, index) => <RMCPicker key={index} prefixCls={pickerPrefixCls} style={{ flex: 1 }} indicatorStyle={indicatorStyle} maskStyle={maskStyle}>
            {col.map(item => {
          return <RMCPickerItem key={item.value} value={item.value}>
                  {item.label}
                </RMCPickerItem>;
        })}
          </RMCPicker>)}
      </RMCMultiPicker>;
  }
}
AtPickerView.options = { addGlobalClass: true };
AtPickerView.defaultProps = getDefaultProps();